@@ -48,7 +48,7 @@ class Kola(kola.Kola):
 
                 return result
 
-            self.events.repeat_timer += safe_func(func_wrapper)
+            self.events.repeat_timer += functools.partial(gevent.spawn_later, interval, func_wrapper)
             return func_wrapper
         return inner_repeat_timer
 
