@@ -28,6 +28,6 @@ class Blueprint(kola.Blueprint):
 
                 return result
 
-            self.events.repeat_app_timer += safe_func(func_wrapper)
+            self.events.repeat_app_timer += functools.partial(gevent.spawn_later, interval, func_wrapper)
             return func_wrapper
         return inner_repeat_timer
