@@ -63,32 +63,7 @@ class GStream(object):
             logger.error('only support \\n as terminator for now, terminator: %s', terminator)
             raise TypeError('only support \\n as terminator for now')
 
-        self.readline(on_read_complete)
-
-    def readline(self, on_read_complete):
-        """
-        接收消息
-        """
-
-        if not self.rfile:
-            return
-
-        # 异常也认为服务器断掉链接了，或者该断掉链接
-        try:
-            data = self.rfile.readline()
-        except Exception, e:
-            logger.exception('rfile.readline fail. e: %s', e)
-            data = None
-
-        if not data:
-            # 重复调用也没关系
-            self.close()
-
-            if self.on_close_callback:
-                safe_call(self.on_close_callback)
-            return
-
-        safe_call(on_read_complete, data)
+        self._readline(on_read_complete)
 
     def write(self, data, callback=None):
         """
@@ -119,3 +94,28 @@ class GStream(object):
                     self.sock.family in (socket.AF_INET, socket.AF_INET6)):
             safe_call(self.sock.setsockopt,
                       socket.IPPROTO_TCP, socket.TCP_NODELAY, 1 if value else 0)
+
+    def _readline(self, on_read_complete):
+        """
+        接收一行消息
+        """
+
+        if not self.rfile:
+            return
+
+        # 异常也认为服务器断掉链接了，或者该断掉链接
+        try:
+            data = self.rfile.readline()
+        except Exception, e:
+            logger.exception('rfile.readline fail. e: %s', e)
+            data = None
+
+        if not data:
+            # 重复调用也没关系
+            self.close()
+
+            if self.on_close_callback:
+                safe_call(self.on_close_callback)
+            return
+
+        safe_call(on_read_complete, data)
